%global with_doc %{!?_without_doc:1}%{?_without_doc:0}
%global git_snaptag 1702
%global git_commit g490e674

%{!?upstream_version:   %global upstream_version         %{version}.dev%{git_snaptag}.%{git_commit}}

# openstack-packstack ----------------------------------------------------------

Name:           openstack-packstack
Epoch:          1
Version:        7.0.0
Release:        0.14.dev%{git_snaptag}.%{git_commit}%{?dist}
Summary:        Openstack Install Utility

Group:          Applications/System
License:        ASL 2.0 and GPLv2
URL:            https://github.com/openstack/packstack
# Tarball is created by bin/release.sh
Source0:        http://mmagr.fedorapeople.org/downloads/packstack/packstack-%{upstream_version}.tar.gz
Patch0:         0001-disable-installing-nagios.patch
Patch1:         0002-Change-documentation-URL.patch
Patch2:         0003-Remove-the-Manila-plugin.patch

BuildArch:      noarch

BuildRequires:  python2-devel
BuildRequires:  python-setuptools

Requires:       openssh-clients
Requires:       python-netaddr
Requires:       openstack-packstack-puppet == %{epoch}:%{version}-%{release}
Requires:       openstack-puppet-modules >= 2014.2.10
Obsoletes:      packstack-modules-puppet
Requires:       python-setuptools
Requires:       PyYAML
Requires:       python-docutils
Requires:       pyOpenSSL
Requires:       iproute
Requires:       libselinux-utils
Requires:       initscripts


%description
Packstack is a utility that uses Puppet modules to install OpenStack. Packstack
can be used to deploy various parts of OpenStack on multiple pre installed
servers over ssh.


# openstack-packstack-puppet ---------------------------------------------------

%package puppet
Summary:        Packstack Puppet module
Group:          Development/Libraries

%description puppet
Puppet module used by Packstack to install OpenStack


# openstack-packstack-doc ------------------------------------------------------

%if 0%{?with_doc}
%package doc
Summary:          Documentation for Packstack
Group:            Documentation

%if 0%{?rhel} == 6
BuildRequires:  python-sphinx10
%else
BuildRequires:  python-sphinx
%endif

%description doc
This package contains documentation files for Packstack.
%endif


# prep -------------------------------------------------------------------------

%prep
%setup -q -n packstack-%{upstream_version}
%patch0 -p1
%patch1 -p1
%patch2 -p1

# Sanitizing a lot of the files in the puppet modules
find packstack/puppet/modules \( -name .fixtures.yml -o -name .gemfile -o -name ".travis.yml" -o -name .rspec \) -exec rm {} +
find packstack/puppet/modules \( -name "*.py" -o -name "*.rb" -o -name "*.pl" \) -exec sed -i '/^#!/{d;q}' {} + -exec chmod -x {} +
find packstack/puppet/modules \( -name "*.sh" \) -exec sed -i 's/^#!.*/#!\/bin\/bash/g' {} + -exec chmod +x {} +
find packstack/puppet/modules -name site.pp -size 0 -exec rm {} +
find packstack/puppet/modules \( -name spec -o -name ext \) | xargs rm -rf

# Moving this data directory out temporarily as it causes setup.py to throw errors
rm -rf %{_builddir}/puppet
mv packstack/puppet %{_builddir}/puppet


# build ------------------------------------------------------------------------

%build
%{__python} setup.py build

%if 0%{?with_doc}
cd docs
%if 0%{?rhel} == 6
make man SPHINXBUILD=sphinx-1.0-build
%else
make man
%endif
%endif


# install ----------------------------------------------------------------------

%install
%{__python} setup.py install --skip-build --root %{buildroot}

# Delete tests
rm -fr %{buildroot}%{python_sitelib}/tests

# Install Puppet module
mkdir -p %{buildroot}/%{_datadir}/openstack-puppet/modules
cp -r %{_builddir}/puppet/modules/packstack  %{buildroot}/%{_datadir}/openstack-puppet/modules/

# Move packstack documentation
mkdir -p %{buildroot}/%{_datadir}/packstack
install -p -D -m 644 docs/packstack.rst %{buildroot}/%{_datadir}/packstack

# Move Puppet manifest templates back to original place
mkdir -p %{buildroot}/%{python_sitelib}/packstack/puppet
mv %{_builddir}/puppet/templates %{buildroot}/%{python_sitelib}/packstack/puppet/

%if 0%{?with_doc}
mkdir -p %{buildroot}%{_mandir}/man1
install -p -D -m 644 docs/_build/man/*.1 %{buildroot}%{_mandir}/man1/
%endif

# Remove docs directory
rm -fr %{buildroot}%{python_sitelib}/docs

# files ------------------------------------------------------------------------

%files
%doc LICENSE
%{_bindir}/packstack
%{_datadir}/packstack
%{python_sitelib}/packstack
%{python_sitelib}/packstack-*.egg-info

%files puppet
%defattr(644,root,root,755)
%{_datadir}/openstack-puppet/modules/packstack

%if 0%{?with_doc}
%files doc
%{_mandir}/man1/packstack.1.gz
%endif


# changelog --------------------------------------------------------------------

%changelog

* Wed Mar 23 2016 Iván Chavero <ichavero@redhat.com> - 7.0.0-0.14.dev1702.g490e674
- Remove the Manila plugin (rhbz#1304043)

* Mon Mar 14 2016 Iván Chavero <ichavero@redhat.com> - 7.0.0-0.13.dev1702.g490e674
- Set manila nova_flavor id (rhbz#1304104)
- Remove S3 endpoint (rhbz#1317110)
- Use correct endpoint name (rhbz#1306547)
- Change documentation URL (rhbz#1308525)

* Thu Feb 18 2016 Iván Chavero <ichavero@redhat.com> - 7.0.0-0.12.dev1699.g8f54936
- Enable VPN tab in Horizon when enabling VPNaaS (rhbz#1297733)
- Fix Trove api-paste.ini path
- Use absolute path for Trove's api-paste.ini (rhbz#1282928)
- Add notification driver (rhbz#1283261)
- Drop dependancy on puppet-galera (rhbz#1283261)

* Sun Jan 31 2016 Iván Chavero <ichavero@redhat.com> - 7.0.0-0.11.dev1692.g1b5e83b
- Add package dependencies (rhbz#1285502)
- Install service_plugins packages on neutron api node (rhbz#1301680)
- Remove nova-network workarounds (rhbz#1298964)
- Fix lvm.conf edition (rhbz#1297712)
- Switch to PyMySQL (rhbz#1266028)

* Mon Jan 04 2016 Martin Mágr <mmagr@redhat.com> - 1:7.0.0-0.10.dev1684.g87ec498
- Rebased to upstream liberty (rhbz#1293730)

* Fri Dec 18 2015 Iván Chavero <ichavero@redhat.com> - 1:7.0.0-0.9..dev1661.gaf13b7e
- Add Adapt to newest puppet-keystone (rhbz#1292923)

* Thu Dec 10 2015 Iván Chavero <ichavero@redhat.com> 1:7.0.0-0.8..dev1661.gaf13b7e
- [Neutron] Added 0002-Correctly-construct-type-drivers-from-CONFIG_NEUTRON.patch (rhbz#1181131)
- [Neutron] Added 0003-Add-support-for-Neutron-ML2-SR-IOV-mechanism-driver.patch (rhbz#1167099)
- [Neutron] Added Neutron VPNaaS (rhbz#1246825)
- [Swift] Add support for swift-object-expirer (rhbz#1221276)
- [Nova] Fix virbr0 elimination on compute nodes (rhbz#1121130

* Thu Nov 05 2015 Jon Schlueter <jschluet@redhat.com> 1:7.0.0-0.7..dev1661.gaf13b7e
- dropping python2-iso8601 patch

* Fri Oct 30 2015 Jon Schlueter <jschluet@redhat.com> 1:7.0.0-0.6.dev1661.gaf13b7e
- fix python2-iso8601 package name to deal with package check

* Fri Oct 30 2015 Jon Schlueter <jschluet@redhat.com> 1:7.0.0-0.5.dev1661.gaf13b7e
- disable nagios install option

* Thu Oct 29 2015  Javier Peña <jpena@redhat.com> - 7.0.0-0.4.dev1661.gaf13b7e
- Use epoch in dependency for openstack-packstack-puppet

* Mon Oct 26 2015  Martin Mágr <mmagr@redhat.com> - 7.0.0-0.3.dev1661.gaf13b7e
-  Liberty rebase

* Sat Oct 10 2015  Alan Pevec <apevec@redhat.com> - 2015.2-0.1.dev.dev1654.gcbbf46e
-  Liberty release candidate
